# -*- coding: utf-8 -*-
###############################################################################~!!~~!!!
#
# Copyright (c) 2010-2012, OPENTIA Group (<http://opentia.com>)
# The word "OPENTIA" is an European Community Trademark property of the Opentia Group
#
# @author: Opentia "Happy Hacking" Team
# @e-mail: consultoria@opentia·es
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################~!!~~!!!
from osv import fields,osv
from tools.translate import _

class purchase_order(osv.osv):

    _inherit = "purchase.order"

    STATE_SELECTION = [
        ('draft', 'Request for Quotation'),
        ('draftready', 'Quotation Ready to Supervision'),
        ('draftpass', 'Quotation Passed Supervision'),
        ('wait', 'Waiting'),
        ('confirmed', 'Waiting Approval'),
        ('approved', 'Approved'),
        ('except_picking', 'Shipping Exception'),
        ('except_invoice', 'Invoice Exception'),
        ('done', 'Done'),
        ('cancel', 'Cancelled')
    ]

    _columns = {
        'state': fields.selection(STATE_SELECTION, 'State', readonly=True, help="The state of the purchase order or the quotation request. A quotation is a purchase order in a 'Draft' state. Then the order has to be confirmed by the user, the state switch to 'Confirmed'. Then the supplier must confirm the order to change the state to 'Approved'. When the purchase order is paid and received, the state becomes 'Done'. If a cancel action occurs in the invoice or in the reception of goods, the state becomes in exception.", select=True),
    }

    def action_draftready(self, cr, uid, ids, context=None):
        todo = []
        for po in self.browse(cr, uid, ids, context=context):
            if not po.order_line:
                raise osv.except_osv(_('Error !'),_('You can not send to Supervisor Purchase Orders without Purchase Order Lines!'))
        for id in ids:
            self.write(cr, uid, [id], {'state' : 'draftready'})
            message = _("Purchase order draft '%s', ready to supervision.") % (po.name,)
            self.log(cr, uid, po.id, message)
        return True

    def action_draftpass(self, cr, uid, ids, context=None):
        todo = []
        for po in self.browse(cr, uid, ids, context=context):
            if not po.order_line:
                raise osv.except_osv(_('Error !'),_('You can not proceed without Purchase Order Lines.'))
        for id in ids:
            self.write(cr, uid, [id], {'state' : 'draftpass'})
            message = _("Purchase order draft '%s', supervised and ready to be confirmed.") % (po.name,)
            self.log(cr, uid, po.id, message)
        return True


purchase_order()

# vim:autoindent:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
